@@ -21,7 +21,18 @@ class PyroConverter:
     ndraws = None  # type: int
 
     def __init__(
-        self, *, posterior=None, prior=None, posterior_predictive=None, coords=None, dims=None
+        self,
+        *,
+        posterior=None,
+        prior=None,
+        posterior_predictive=None,
+        predictions=None,
+        constant_data=None,
+        predictions_constant_data=None,
+        coords=None,
+        dims=None,
+        pred_dims=None,
+        num_chains=1,
     ):
         """Convert Pyro data into an InferenceData object.
 
@@ -33,22 +44,35 @@ class PyroConverter:
             Prior samples from a Pyro model
         posterior_predictive : dict
             Posterior predictive samples for the posterior
+        predictions: dict
+            Out of sample predictions
+        constant_data: dict
+            Dictionary containing constant data variables mapped to their values.
+        predictions_constant_data: dict
+            Constant data used for out-of-sample predictions.
         coords : dict[str] -> list[str]
             Map of dimensions to coordinates
         dims : dict[str] -> list[str]
             Map variable names to their coordinates
+        pred_dims: dict
+            Dims for predictions data. Map variable names to their coordinates.
+        num_chains: int
+            Number of chains used for sampling. Ignored if posterior is present.
         """
         self.posterior = posterior
-        if posterior is not None:
-            self.nchains, self.ndraws = posterior.num_chains, posterior.num_samples
-        else:
-            self.nchains = self.ndraws = 0
         self.prior = prior
         self.posterior_predictive = posterior_predictive
+        self.predictions = predictions
+        self.constant_data = constant_data
+        self.predictions_constant_data = predictions_constant_data
         self.coords = coords
         self.dims = dims
+        self.pred_dims = pred_dims
         import pyro
 
+        def arbitrary_element(dct):
+            return next(iter(dct.values()))
+
         self.pyro = pyro
         if posterior is not None:
             self.nchains, self.ndraws = posterior.num_chains, posterior.num_samples
@@ -58,7 +82,22 @@ class PyroConverter:
                 self._args = self.posterior._args  # pylint: disable=protected-access
                 self._kwargs = self.posterior._kwargs  # pylint: disable=protected-access
         else:
-            self.nchains = self.ndraws = 0
+            self.nchains = num_chains
+            get_from = None
+            if predictions is not None:
+                get_from = predictions
+            elif posterior_predictive is not None:
+                get_from = posterior_predictive
+            elif prior is not None:
+                get_from = prior
+            if get_from is None and constant_data is None and predictions_constant_data is None:
+                raise ValueError(
+                    "When constructing InferenceData must have at least"
+                    " one of posterior, prior, posterior_predictive or predictions."
+                )
+            if get_from is not None:
+                aelem = arbitrary_element(get_from)
+                self.ndraws = aelem.shape[0] // self.nchains
 
         observations = {}
         if self.model is not None:
@@ -107,11 +146,10 @@ class PyroConverter:
                 return None
         return dict_to_dataset(data, library=self.pyro, coords=self.coords, dims=self.dims)
 
-    @requires("posterior_predictive")
-    def posterior_predictive_to_xarray(self):
-        """Convert posterior_predictive samples to xarray."""
+    def translate_posterior_predictive_dict_to_xarray(self, dct, dims):
+        """Convert posterior_predictive or prediction samples to xarray."""
         data = {}
-        for k, ary in self.posterior_predictive.items():
+        for k, ary in dct.items():
             ary = ary.detach().cpu().numpy()
             shape = ary.shape
             if shape[0] == self.nchains and shape[1] == self.ndraws:
@@ -124,7 +162,19 @@ class PyroConverter:
                     "posterior predictive shape not compatible with number of chains and draws."
                     "This can mean that some draws or even whole chains are not represented."
                 )
-        return dict_to_dataset(data, library=self.pyro, coords=self.coords, dims=self.dims)
+        return dict_to_dataset(data, library=self.pyro, coords=self.coords, dims=dims)
+
+    @requires("posterior_predictive")
+    def posterior_predictive_to_xarray(self):
+        """Convert posterior_predictive samples to xarray."""
+        return self.translate_posterior_predictive_dict_to_xarray(
+            self.posterior_predictive, self.dims
+        )
+
+    @requires("predictions")
+    def predictions_to_xarray(self):
+        """Convert predictions to xarray."""
+        return self.translate_posterior_predictive_dict_to_xarray(self.predictions, self.pred_dims)
 
     def priors_to_xarray(self):
         """Convert prior samples (and if possible prior predictive too) to xarray."""
@@ -175,6 +225,32 @@ class PyroConverter:
             observed_data[name] = xr.DataArray(vals, dims=val_dims, coords=coords)
         return xr.Dataset(data_vars=observed_data, attrs=make_attrs(library=self.pyro))
 
+    def convert_constant_data_to_xarray(self, dct, dims):
+        """Convert constant_data or predictions_constant_data to xarray."""
+        if dims is None:
+            dims = {}
+        constant_data = {}
+        for name, vals in dct.items():
+            vals = utils.one_de(vals)
+            val_dims = dims.get(name)
+            val_dims, coords = generate_dims_coords(
+                vals.shape, name, dims=val_dims, coords=self.coords
+            )
+            # filter coords based on the dims
+            coords = {key: xr.IndexVariable((key,), data=coords[key]) for key in val_dims}
+            constant_data[name] = xr.DataArray(vals, dims=val_dims, coords=coords)
+        return xr.Dataset(data_vars=constant_data, attrs=make_attrs(library=self.pyro))
+
+    @requires("constant_data")
+    def constant_data_to_xarray(self):
+        """Convert constant_data to xarray."""
+        return self.convert_constant_data_to_xarray(self.constant_data, self.dims)
+
+    @requires("predictions_constant_data")
+    def predictions_constant_data_to_xarray(self):
+        """Convert predictions_constant_data to xarray."""
+        return self.convert_constant_data_to_xarray(self.predictions_constant_data, self.pred_dims)
+
     def to_inference_data(self):
         """Convert all available data to an InferenceData object."""
         return InferenceData(
@@ -183,15 +259,33 @@ class PyroConverter:
                 "sample_stats": self.sample_stats_to_xarray(),
                 "log_likelihood": self.log_likelihood_to_xarray(),
                 "posterior_predictive": self.posterior_predictive_to_xarray(),
+                "predictions": self.predictions_to_xarray(),
+                "constant_data": self.constant_data_to_xarray(),
+                "predictions_constant_data": self.predictions_constant_data_to_xarray(),
                 **self.priors_to_xarray(),
                 "observed_data": self.observed_data_to_xarray(),
             }
         )
 
 
-def from_pyro(posterior=None, *, prior=None, posterior_predictive=None, coords=None, dims=None):
+def from_pyro(
+    posterior=None,
+    *,
+    prior=None,
+    posterior_predictive=None,
+    predictions=None,
+    constant_data=None,
+    predictions_constant_data=None,
+    coords=None,
+    dims=None,
+    pred_dims=None,
+    num_chains=1,
+):
     """Convert Pyro data into an InferenceData object.
 
+    For a usage example read the
+    :doc:`Cookbook section on from_pyro </notebooks/InferenceDataCookbook>`
+
     Parameters
     ----------
     posterior : pyro.infer.MCMC
@@ -200,15 +294,30 @@ def from_pyro(posterior=None, *, prior=None, posterior_predictive=None, coords=N
         Prior samples from a Pyro model
     posterior_predictive : dict
         Posterior predictive samples for the posterior
+    predictions: dict
+        Out of sample predictions
+    constant_data: dict
+        Dictionary containing constant data variables mapped to their values.
+    predictions_constant_data: dict
+        Constant data used for out-of-sample predictions.
     coords : dict[str] -> list[str]
         Map of dimensions to coordinates
     dims : dict[str] -> list[str]
         Map variable names to their coordinates
+    pred_dims: dict
+        Dims for predictions data. Map variable names to their coordinates.
+    num_chains: int
+        Number of chains used for sampling. Ignored if posterior is present.
     """
     return PyroConverter(
         posterior=posterior,
         prior=prior,
         posterior_predictive=posterior_predictive,
+        predictions=predictions,
+        constant_data=constant_data,
+        predictions_constant_data=predictions_constant_data,
         coords=coords,
         dims=dims,
+        pred_dims=pred_dims,
+        num_chains=num_chains,
     ).to_inference_data()
