@@ -1,5 +1,7 @@
 """Matplotib Posterior predictive plot."""
-from matplotlib import animation
+import platform
+import logging
+from matplotlib import animation, get_backend
 import matplotlib.pyplot as plt
 import numpy as np
 
@@ -8,10 +10,10 @@ from ...kdeplot import plot_kde
 from ...plot_utils import (
     make_label,
     _create_axes_grid,
-    get_bins,
-    _fast_kde,
 )
-from ....stats.stats_utils import histogram
+from ....numeric_utils import _fast_kde, histogram, get_bins
+
+_log = logging.getLogger(__name__)
 
 
 def plot_ppc(
@@ -42,6 +44,26 @@ def plot_ppc(
     show,
 ):
     """Matplotlib ppc plot."""
+    if animated:
+        try:
+            shell = get_ipython().__class__.__name__
+            if shell == "ZMQInteractiveShell" and get_backend() != "nbAgg":
+                raise Warning(
+                    "To run animations inside a notebook you have to use the nbAgg backend. "
+                    "Try with `%matplotlib notebook` or  `%matplotlib  nbAgg`. You can switch "
+                    "back to the default backend with `%matplotlib  inline` or "
+                    "`%matplotlib  auto`."
+                )
+        except NameError:
+            pass
+
+        if animation_kwargs["blit"] and platform.system() != "Linux":
+            _log.warning(
+                "If you experience problems rendering the animation try setting "
+                "`animation_kwargs({'blit':False}) or changing the plotting backend "
+                "(e.g. to TkAgg)"
+            )
+
     if ax is None:
         fig, axes = _create_axes_grid(
             length_plotters, rows, cols, figsize=figsize, backend_kwargs=backend_kwargs
