@@ -114,27 +114,36 @@ def make_ufunc(
     elif check_shape is None:
         check_shape = False
 
-    def _ufunc(*args, out=None, **kwargs):
+    def _ufunc(*args, out=None, out_shape=None, **kwargs):
         """General ufunc for single-output function."""
         arys = args[:n_input]
+        n_dims_out = None
         if out is None:
-            out = np.empty(arys[-1].shape[:-n_dims])
+            if out_shape is None:
+                out = np.empty(arys[-1].shape[:-n_dims])
+            else:
+                out = np.empty((*arys[-1].shape[:-n_dims], *out_shape))
+                n_dims_out = -len(out_shape)
         elif check_shape:
             if out.shape != arys[-1].shape[:-n_dims]:
                 msg = "Shape incorrect for `out`: {}.".format(out.shape)
                 msg += " Correct shape is {}".format(arys[-1].shape[:-n_dims])
                 raise TypeError(msg)
-        for idx in np.ndindex(out.shape):
+        for idx in np.ndindex(out.shape[:n_dims_out]):
             arys_idx = [ary[idx].ravel() if ravel else ary[idx] for ary in arys]
             out[idx] = np.asarray(func(*arys_idx, *args[n_input:], **kwargs))[index]
         return out
 
-    def _multi_ufunc(*args, out=None, **kwargs):
+    def _multi_ufunc(*args, out=None, out_shape=None, **kwargs):
         """General ufunc for multi-output function."""
         arys = args[:n_input]
         element_shape = arys[-1].shape[:-n_dims]
         if out is None:
-            out = tuple(np.empty(element_shape) for _ in range(n_output))
+            if out_shape is None:
+                out = tuple(np.empty(element_shape) for _ in range(n_output))
+            else:
+                out = tuple(np.empty((*element_shape, *out_shape[i])) for i in range(n_output))
+
         elif check_shape:
             raise_error = False
             correct_shape = tuple(element_shape for _ in range(n_output))
@@ -185,6 +194,7 @@ def wrap_xarray_ufunc(
         Arguments passed to 'ufunc'.
     func_kwargs : dict
         Keyword arguments passed to 'ufunc'.
+            - 'out_shape', int, by default None
     **kwargs
         Passed to xarray.apply_ufunc.
 
@@ -200,13 +210,14 @@ def wrap_xarray_ufunc(
     if func_kwargs is None:
         func_kwargs = {}
 
-    callable_ufunc = make_ufunc(ufunc, **ufunc_kwargs)
-
     kwargs.setdefault(
-        "input_core_dims", tuple(("chain", "draw") for _ in range(len(func_args) + 1))
+        "input_core_dims", tuple(("chain", "draw") for _ in range(len(func_args) + len(datasets)))
     )
+    ufunc_kwargs.setdefault("n_dims", len(kwargs["input_core_dims"][-1]))
     kwargs.setdefault("output_core_dims", tuple([] for _ in range(ufunc_kwargs.get("n_output", 1))))
 
+    callable_ufunc = make_ufunc(ufunc, **ufunc_kwargs)
+
     return apply_ufunc(callable_ufunc, *datasets, *func_args, kwargs=func_kwargs, **kwargs)
 
 
@@ -391,16 +402,14 @@ def get_log_likelihood(idata, var_name=None):
     """Retrieve the log likelihood dataarray of a given variable."""
     if hasattr(idata, "sample_stats") and hasattr(idata.sample_stats, "log_likelihood"):
         warnings.warn(
-            "Storing the log_likelihood in sample_stats groups will be deprecated",
-            PendingDeprecationWarning,
+            "Storing the log_likelihood in sample_stats groups has been deprecated",
+            DeprecationWarning,
         )
         return idata.sample_stats.log_likelihood
     if not hasattr(idata, "log_likelihood"):
         raise TypeError("log likelihood not found in inference data object")
     if var_name is None:
         var_names = list(idata.log_likelihood.data_vars)
-        if "lp" in var_names:
-            var_names.remove("lp")
         if len(var_names) > 1:
             raise TypeError(
                 "Found several log likelihood arrays {}, var_name cannot be None".format(var_names)
@@ -428,6 +437,11 @@ Pareto k diagnostic values:
    (0.7, 1]   (bad)      {{4:{0}d}} {{8:6.1f}}%
    (1, Inf)   (very bad) {{5:{0}d}} {{9:6.1f}}%
 """
+SCALE_WARNING_FORMAT = """
+The scale is now log by default. Use 'scale' argument or 'stats.ic_scale' rcParam if
+you rely on a specific value.
+A higher log-score (or a lower deviance) indicates a model with better predictive
+accuracy."""
 SCALE_DICT = {"deviance": "deviance", "log": "elpd", "negative_log": "-elpd"}
 
 
@@ -464,6 +478,7 @@ class ELPDData(pd.Series):  # pylint: disable=too-many-ancestors
                 "Count", "Pct.", *[*counts, *(counts / np.sum(counts) * 100)]
             )
             base = "\n".join([base, extended])
+        base = "\n".join([base, SCALE_WARNING_FORMAT])
         return base
 
     def __repr__(self):
