@@ -1,21 +1,22 @@
 """Tests use the 'bokeh' backend."""
 # pylint: disable=redefined-outer-name,too-many-lines
 from copy import deepcopy
-import bokeh.plotting as bkp
-from pandas import DataFrame
+
 import numpy as np
 import pytest
+from pandas import DataFrame  # pylint: disable=wrong-import-position
 
-from ...data import from_dict, load_arviz_data
-from ..helpers import (  # pylint: disable=unused-import
-    eight_schools_params,
-    models,
+from ...data import from_dict, load_arviz_data  # pylint: disable=wrong-import-position
+from ..helpers import (  # pylint: disable=unused-import, wrong-import-position
     create_model,
-    multidim_models,
     create_multidimensional_model,
+    eight_schools_params,
+    importorskip,
+    models,
+    multidim_models,
 )
-from ...rcparams import rcParams, rc_context
-from ...plots import (
+from ...rcparams import rc_context, rcParams  # pylint: disable=wrong-import-position
+from ...plots import (  # pylint: disable=wrong-import-position
     plot_autocorr,
     plot_compare,
     plot_density,
@@ -24,21 +25,25 @@ from ...plots import (
     plot_energy,
     plot_ess,
     plot_forest,
-    plot_hpd,
+    plot_hdi,
     plot_joint,
     plot_kde,
     plot_khat,
     plot_loo_pit,
     plot_mcse,
     plot_pair,
-    plot_rank,
-    plot_trace,
     plot_parallel,
     plot_posterior,
     plot_ppc,
+    plot_rank,
+    plot_trace,
     plot_violin,
 )
-from ...stats import compare, loo, waic
+from ...stats import compare, loo, waic  # pylint: disable=wrong-import-position
+
+# Skip tests if bokeh not installed
+bkp = importorskip("bokeh.plotting")  # pylint: disable=invalid-name
+
 
 rcParams["data.load"] = "eager"
 
@@ -71,10 +76,10 @@ def continuous_model():
     [
         {"point_estimate": "mean"},
         {"point_estimate": "median"},
-        {"credible_interval": 0.94},
-        {"credible_interval": 1},
+        {"hdi_prob": 0.94},
+        {"hdi_prob": 1},
         {"outline": True},
-        {"hpd_markers": ["v"]},
+        {"hdi_markers": ["v"]},
         {"shade": 1},
     ],
 )
@@ -112,7 +117,7 @@ def test_plot_density_bad_kwargs(models):
         )
 
     with pytest.raises(ValueError):
-        plot_density(obj, credible_interval=2, backend="bokeh", show=False)
+        plot_density(obj, hdi_prob=2, backend="bokeh", show=False)
 
 
 @pytest.mark.parametrize(
@@ -126,6 +131,8 @@ def test_plot_density_bad_kwargs(models):
         {"combined": True, "compact": True, "legend": True},
         {"divergences": "top"},
         {"divergences": False},
+        {"kind": "rank_vlines"},
+        {"kind": "rank_bars"},
         {"lines": [("mu", {}, [1, 2])]},
         {"lines": [("mu", {}, 8)]},
     ],
@@ -481,8 +488,8 @@ def test_plot_forest_bad(models, model_fits):
         {"smooth": False},
     ],
 )
-def test_plot_hpd(models, data, kwargs):
-    axis = plot_hpd(
+def test_plot_hdi(models, data, kwargs):
+    axis = plot_hdi(
         data["y"], models.model_1.posterior["theta"], backend="bokeh", show=False, **kwargs
     )
     assert axis
@@ -595,9 +602,9 @@ def test_plot_khat_bad_input(models):
     [
         {},
         {"n_unif": 50},
-        {"use_hpd": True, "color": "gray"},
-        {"use_hpd": True, "credible_interval": 0.68, "plot_kwargs": {"alpha": 0.9}},
-        {"use_hpd": True, "hpd_kwargs": {"smooth": False}},
+        {"use_hdi": True, "color": "gray"},
+        {"use_hdi": True, "credible_interval": 0.68, "plot_kwargs": {"alpha": 0.9}},
+        {"use_hdi": True, "hdi_kwargs": {"smooth": False}},
         {"ecdf": True},
         {"ecdf": True, "ecdf_fill": False, "plot_unif_kwargs": {"line_dash": "--"}},
         {"ecdf": True, "credible_interval": 0.97, "fill_kwargs": {"color": "red"}},
@@ -609,10 +616,10 @@ def test_plot_loo_pit(models, kwargs):
 
 
 def test_plot_loo_pit_incompatible_args(models):
-    """Test error when both ecdf and use_hpd are True."""
+    """Test error when both ecdf and use_hdi are True."""
     with pytest.raises(ValueError, match="incompatible"):
         plot_loo_pit(
-            idata=models.model_1, y="y", ecdf=True, use_hpd=True, backend="bokeh", show=False
+            idata=models.model_1, y="y", ecdf=True, use_hdi=True, backend="bokeh", show=False
         )
 
 
@@ -703,6 +710,11 @@ def test_plot_mcse_no_divergences(models):
             "coords": {"theta_dim_0": [0, 1]},
             "textsize": 20,
         },
+        {
+            "point_estimate": "mean",
+            "reference_values": {"mu": 0, "tau": 0},
+            "reference_values_kwargs": {"line_color": "blue"},
+        },
     ],
 )
 def test_plot_pair(models, kwargs):
@@ -712,7 +724,9 @@ def test_plot_pair(models, kwargs):
 
 @pytest.mark.parametrize("kwargs", [{"kind": "scatter"}, {"kind": "kde"}, {"kind": "hexbin"}])
 def test_plot_pair_2var(discrete_model, kwargs):
-    ax = plot_pair(discrete_model, ax=bkp.figure(), backend="bokeh", show=False, **kwargs)
+    ax = plot_pair(
+        discrete_model, ax=np.atleast_2d(bkp.figure()), backend="bokeh", show=False, **kwargs
+    )
     assert ax
 
 
@@ -881,6 +895,7 @@ def test_plot_ppc_ax(models, kind):
         {"point_estimate": "mode"},
         {"point_estimate": "median"},
         {"point_estimate": None},
+        {"hdi_prob": "hide"},
         {"ref_val": 0},
         {"ref_val": None},
         {"ref_val": {"mu": [{"ref_val": 1}]}},
