@@ -34,14 +34,15 @@ from ...plots import (
     plot_compare,
     plot_kde,
     plot_khat,
-    plot_hpd,
+    plot_hdi,
     plot_dist,
     plot_rank,
     plot_elpd,
     plot_loo_pit,
     plot_mcse,
 )
-from ...plots.plot_utils import _fast_kde, _cov
+from ...utils import _cov
+from ...numeric_utils import _fast_kde
 
 rcParams["data.load"] = "eager"
 
@@ -92,19 +93,24 @@ def fig_ax():
     [
         {"point_estimate": "mean"},
         {"point_estimate": "median"},
-        {"credible_interval": 0.94},
-        {"credible_interval": 1},
+        {"hdi_prob": 0.94},
+        {"hdi_prob": 1},
         {"outline": True},
         {"colors": ["g", "b", "r", "y"]},
         {"colors": "k"},
-        {"hpd_markers": ["v"]},
+        {"hdi_markers": ["v"]},
         {"shade": 1},
+        {"transform": lambda x: x + 1},
+        {"ax": plt.subplots(6, 3)[1]},
     ],
 )
 def test_plot_density_float(models, kwargs):
     obj = [getattr(models, model_fit) for model_fit in ["model_1", "model_2"]]
     axes = plot_density(obj, **kwargs)
-    assert axes.shape[0] >= 18
+    if "ax" in kwargs:
+        assert axes.shape == (6, 3)
+    else:
+        assert axes.shape[0] >= 18
 
 
 def test_plot_density_discrete(discrete_model):
@@ -129,7 +135,7 @@ def test_plot_density_bad_kwargs(models):
         plot_density(obj, data_labels=["bad_value_{}".format(i) for i in range(len(obj) + 10)])
 
     with pytest.raises(ValueError):
-        plot_density(obj, credible_interval=2)
+        plot_density(obj, hdi_prob=2)
 
 
 @pytest.mark.parametrize(
@@ -143,6 +149,8 @@ def test_plot_density_bad_kwargs(models):
         {"combined": True, "compact": True, "legend": True},
         {"divergences": "top", "legend": True},
         {"divergences": False},
+        {"kind": "rank_vlines"},
+        {"kind": "rank_bars"},
         {"lines": [("mu", {}, [1, 2])]},
         {"lines": [("mu", {}, 8)]},
     ],
@@ -152,14 +160,18 @@ def test_plot_trace(models, kwargs):
     assert axes.shape
 
 
-@pytest.mark.parametrize("compact", [True, False],)
-@pytest.mark.parametrize("combined", [True, False],)
+@pytest.mark.parametrize(
+    "compact", [True, False],
+)
+@pytest.mark.parametrize(
+    "combined", [True, False],
+)
 def test_plot_trace_legend(compact, combined):
     idata = load_arviz_data("rugby")
     axes = plot_trace(
         idata, var_names=["home", "atts_star"], compact=compact, combined=combined, legend=True
     )
-    assert axes[0, 1].get_legend()
+    assert axes[0, 0].get_legend()
     compact_legend = axes[1, 0].get_legend()
     if compact:
         assert axes.shape == (2, 2)
@@ -201,7 +213,7 @@ def test_plot_trace_bad_lines_value(models, bad_kwargs):
     "args_expected",
     [
         ({}, 1),
-        ({"var_names": "mu"}, 1),
+        ({"var_names": "mu", "transform": lambda x: x + 1}, 1),
         ({"var_names": "mu", "rope": (-1, 1)}, 1),
         ({"r_hat": True, "quartiles": False}, 2),
         ({"var_names": ["mu"], "colors": "C0", "ess": True, "combined": True}, 2),
@@ -234,6 +246,11 @@ def test_plot_forest_single_value():
     assert axes.shape
 
 
+def test_plot_forest_ridge_discrete(discrete_model):
+    axes = plot_forest(discrete_model, kind="ridgeplot")
+    assert axes.shape
+
+
 @pytest.mark.parametrize("model_fits", [["model_1"], ["model_1", "model_2"]])
 def test_plot_forest_bad(models, model_fits):
     obj = [getattr(models, model_fit) for model_fit in model_fits]
@@ -389,12 +406,12 @@ def test_plot_kde_inference_data(models):
             "var_names": "theta",
             "divergences": True,
             "coords": {"theta_dim_0": [0, 1]},
-            "plot_kwargs": {"marker": "x"},
+            "scatter_kwargs": {"marker": "x"},
             "divergences_kwargs": {"marker": "*", "c": "C"},
         },
         {
             "divergences": True,
-            "plot_kwargs": {"marker": "x"},
+            "scatter_kwargs": {"marker": "x"},
             "divergences_kwargs": {"marker": "*", "c": "C"},
             "var_names": ["theta", "mu"],
         },
@@ -406,9 +423,14 @@ def test_plot_kde_inference_data(models):
             "var_names": ["theta"],
             "coords": {"theta_dim_0": [0, 1]},
             "colorbar": True,
-            "plot_kwargs": {"cmap": "viridis"},
+            "hexbin_kwargs": {"cmap": "viridis"},
             "textsize": 20,
         },
+        {
+            "point_estimate": "mean",
+            "reference_values": {"mu": 0, "tau": 0},
+            "reference_values_kwargs": {"c": "C", "marker": "*"},
+        },
     ],
 )
 def test_plot_pair(models, kwargs):
@@ -446,6 +468,16 @@ def test_plot_pair_divergences_warning(has_sample_stats):
     assert np.all(ax)
 
 
+@pytest.mark.parametrize(
+    "kwargs", [{}, {"marginals": True}, {"marginals": True, "var_names": ["mu", "tau"]}]
+)
+def test_plot_pair_overlaid(models, kwargs):
+    ax = plot_pair(models.model_1, **kwargs)
+    ax2 = plot_pair(models.model_2, ax=ax, **kwargs)
+    assert ax is ax2
+    assert ax.shape
+
+
 @pytest.mark.parametrize("kind", ["kde", "cumulative", "scatter"])
 @pytest.mark.parametrize("alpha", [None, 0.2, 1])
 @pytest.mark.parametrize("animated", [False, True])
@@ -697,6 +729,7 @@ def test_plot_rank(models, kwargs):
         {"rope": {"mu": [{"rope": (-2, 2)}], "theta": [{"school": "Choate", "rope": (2, 4)}]}},
         {"point_estimate": "mode"},
         {"point_estimate": "median"},
+        {"hdi_prob": "hide"},
         {"point_estimate": None},
         {"ref_val": 0},
         {"ref_val": None},
@@ -781,8 +814,8 @@ def test_plot_compare_no_ic(models):
         {"smooth": False},
     ],
 )
-def test_plot_hpd(models, data, kwargs):
-    plot_hpd(data["y"], models.model_1.posterior["theta"], **kwargs)
+def test_plot_hdi(models, data, kwargs):
+    plot_hdi(data["y"], models.model_1.posterior["theta"], **kwargs)
 
 
 @pytest.mark.parametrize("limits", [(-10.0, 10.0), (-5, 5), (None, None)])
@@ -1052,9 +1085,9 @@ def test_plot_ess_no_divergences(models):
     [
         {},
         {"n_unif": 50, "legend": False},
-        {"use_hpd": True, "color": "gray"},
-        {"use_hpd": True, "credible_interval": 0.68, "plot_kwargs": {"ls": "--"}},
-        {"use_hpd": True, "hpd_kwargs": {"smooth": False}},
+        {"use_hdi": True, "color": "gray"},
+        {"use_hdi": True, "credible_interval": 0.68, "plot_kwargs": {"ls": "--"}},
+        {"use_hdi": True, "hdi_kwargs": {"smooth": False}},
         {"ecdf": True},
         {"ecdf": True, "ecdf_fill": False, "plot_unif_kwargs": {"ls": "--"}},
         {"ecdf": True, "credible_interval": 0.97, "fill_kwargs": {"hatch": "/"}},
@@ -1066,9 +1099,9 @@ def test_plot_loo_pit(models, kwargs):
 
 
 def test_plot_loo_pit_incompatible_args(models):
-    """Test error when both ecdf and use_hpd are True."""
+    """Test error when both ecdf and use_hdi are True."""
     with pytest.raises(ValueError, match="incompatible"):
-        plot_loo_pit(idata=models.model_1, y="y", ecdf=True, use_hpd=True)
+        plot_loo_pit(idata=models.model_1, y="y", ecdf=True, use_hdi=True)
 
 
 @pytest.mark.parametrize(
