@@ -1,30 +1,29 @@
 # pylint: disable=redefined-outer-name, no-member
 from copy import deepcopy
+
 import numpy as np
-from numpy.testing import assert_allclose, assert_array_almost_equal, assert_array_equal
 import pytest
+from numpy.testing import assert_allclose, assert_array_almost_equal, assert_array_equal
 from scipy.stats import linregress
-from xarray import Dataset, DataArray
+from xarray import DataArray, Dataset
 
-
-from ...data import load_arviz_data, from_dict, convert_to_inference_data, concat
+from ...data import concat, convert_to_inference_data, from_dict, load_arviz_data
+from ...rcparams import rcParams
 from ...stats import (
-    compare,
-    hpd,
-    loo,
-    r2_score,
-    waic,
-    psislw,
-    summary,
-    loo_pit,
-    ess,
     apply_test_function,
+    compare,
+    ess,
+    hdi,
+    loo,
+    loo_pit,
+    psislw,
+    r2_score,
+    summary,
+    waic,
 )
 from ...stats.stats import _gpinv
-from ...utils import Numba
+from ...stats.stats_utils import get_log_likelihood
 from ..helpers import check_multiple_attrs, multidim_models  # pylint: disable=unused-import
-from ...rcparams import rcParams
-
 
 rcParams["data.load"] = "eager"
 
@@ -41,37 +40,83 @@ def non_centered_eight():
     return non_centered_eight
 
 
-def test_hpd():
+def test_hdp():
     normal_sample = np.random.randn(5000000)
-    interval = hpd(normal_sample)
+    interval = hdi(normal_sample)
     assert_array_almost_equal(interval, [-1.88, 1.88], 2)
 
 
-def test_hpd_multimodal():
+def test_hdp_2darray():
+    normal_sample = np.random.randn(12000, 5)
+    result = hdi(normal_sample)
+    assert result.shape == (5, 2)
+
+
+def test_hdi_multidimension():
+    normal_sample = np.random.randn(12000, 10, 3)
+    result = hdi(normal_sample)
+    assert result.shape == (3, 2)
+
+
+def test_hdi_idata(centered_eight):
+    data = centered_eight.posterior
+    result = hdi(data)
+    assert isinstance(result, Dataset)
+    assert dict(result.dims) == {"school": 8, "hdi": 2}
+
+    result = hdi(data, input_core_dims=[["chain"]])
+    assert isinstance(result, Dataset)
+    assert result.dims == {"draw": 500, "hdi": 2, "school": 8}
+
+
+def test_hdi_idata_varnames(centered_eight):
+    data = centered_eight.posterior
+    result = hdi(data, var_names=["mu", "theta"])
+    assert isinstance(result, Dataset)
+    assert result.dims == {"hdi": 2, "school": 8}
+    assert list(result.data_vars.keys()) == ["mu", "theta"]
+
+
+def test_hdi_idata_group(centered_eight):
+    result_posterior = hdi(centered_eight, group="posterior", var_names="mu")
+    result_prior = hdi(centered_eight, group="prior", var_names="mu")
+    assert result_prior.dims == {"hdi": 2}
+    range_posterior = result_posterior.mu.values[1] - result_posterior.mu.values[0]
+    range_prior = result_prior.mu.values[1] - result_prior.mu.values[0]
+    assert range_posterior < range_prior
+
+
+def test_hdi_coords(centered_eight):
+    data = centered_eight.posterior
+    result = hdi(data, coords={"chain": [0, 1, 3]}, input_core_dims=[["draw"]])
+    assert_array_equal(result.coords["chain"], [0, 1, 3])
+
+
+def test_hdi_multimodal():
     normal_sample = np.concatenate(
         (np.random.normal(-4, 1, 2500000), np.random.normal(2, 0.5, 2500000))
     )
-    intervals = hpd(normal_sample, multimodal=True)
+    intervals = hdi(normal_sample, multimodal=True)
     assert_array_almost_equal(intervals, [[-5.8, -2.2], [0.9, 3.1]], 1)
 
 
-def test_hpd_circular():
+def test_hdi_circular():
     normal_sample = np.random.vonmises(np.pi, 1, 5000000)
-    interval = hpd(normal_sample, circular=True)
+    interval = hdi(normal_sample, circular=True)
     assert_array_almost_equal(interval, [0.6, -0.6], 1)
 
 
-def test_hpd_bad_ci():
+def test_hdi_bad_ci():
     normal_sample = np.random.randn(10)
     with pytest.raises(ValueError):
-        hpd(normal_sample, credible_interval=2)
+        hdi(normal_sample, hdi_prob=2)
 
 
-def test_hpd_skipna():
+def test_hdi_skipna():
     normal_sample = np.random.randn(500)
-    interval = hpd(normal_sample[10:])
+    interval = hdi(normal_sample[10:])
     normal_sample[:10] = np.nan
-    interval_ = hpd(normal_sample, skipna=True)
+    interval_ = hdi(normal_sample, skipna=True)
     assert_array_almost_equal(interval, interval_)
 
 
@@ -154,21 +199,11 @@ def test_summary_var_names(centered_eight, var_names_expected):
     assert len(summary_df.index) == expected
 
 
-@pytest.mark.parametrize("include_circ", [True, False])
-def test_summary_include_circ(centered_eight, include_circ):
-    assert summary(centered_eight, include_circ=include_circ) is not None
-    state = Numba.numba_flag
-    Numba.disable_numba()
-    assert summary(centered_eight, include_circ=include_circ) is not NotImplementedError
-    Numba.enable_numba()
-    assert state == Numba.numba_flag
-
-
 METRICS_NAMES = [
     "mean",
     "sd",
-    "hpd_3%",
-    "hpd_97%",
+    "hdi_3%",
+    "hdi_97%",
     "mcse_mean",
     "mcse_sd",
     "ess_mean",
@@ -395,12 +430,11 @@ def test_loo_print(centered_eight, scale):
     assert loo_data is not None
     assert loo_pointwise is not None
     assert len(loo_data) < len(loo_pointwise)
-    assert loo_data == loo_pointwise[: len(loo_data)]
 
 
 def test_psislw(centered_eight):
     pareto_k = loo(centered_eight, pointwise=True, reff=0.7)["pareto_k"]
-    log_likelihood = centered_eight.sample_stats.log_likelihood  # pylint: disable=no-member
+    log_likelihood = get_log_likelihood(centered_eight)
     log_likelihood = log_likelihood.stack(sample=("chain", "draw"))
     assert_allclose(pareto_k, psislw(-log_likelihood, 0.7)[1])
 
@@ -460,7 +494,7 @@ def test_loo_pit(centered_eight, args):
     log_weights = args.get("log_weights", None)
     y_arr = centered_eight.observed_data.obs
     y_hat_arr = centered_eight.posterior_predictive.obs.stack(sample=("chain", "draw"))
-    log_like = centered_eight.sample_stats.log_likelihood.stack(sample=("chain", "draw"))
+    log_like = get_log_likelihood(centered_eight).stack(sample=("chain", "draw"))
     n_samples = len(log_like.sample)
     ess_p = ess(centered_eight.posterior, method="mean")
     reff = np.hstack([ess_p[v].values.flatten() for v in ess_p.data_vars]).mean() / n_samples
@@ -500,7 +534,7 @@ def test_loo_pit_multidim(multidim_models, args):
     idata = multidim_models.model_1
     y_arr = idata.observed_data.y
     y_hat_arr = idata.posterior_predictive.y.stack(sample=("chain", "draw"))
-    log_like = idata.sample_stats.log_likelihood.stack(sample=("chain", "draw"))
+    log_like = get_log_likelihood(idata).stack(sample=("chain", "draw"))
     n_samples = len(log_like.sample)
     ess_p = ess(idata.posterior, method="mean")
     reff = np.hstack([ess_p[v].values.flatten() for v in ess_p.data_vars]).mean() / n_samples
@@ -630,21 +664,3 @@ def test_apply_test_function_should_overwrite_error(centered_eight):
     """Test error when overwrite=False but out_name is already a present variable."""
     with pytest.raises(ValueError, match="Should overwrite"):
         apply_test_function(centered_eight, lambda y, theta: y, out_name_data="obs")
-
-
-def test_numba_stats():
-    """Numba test for r2_score"""
-    state = Numba.numba_flag  # Store the current state of Numba
-    set_1 = np.random.randn(100, 100)
-    set_2 = np.random.randn(100, 100)
-    set_3 = np.random.rand(100)
-    set_4 = np.random.rand(100)
-    Numba.disable_numba()
-    non_numba = r2_score(set_1, set_2)
-    non_numba_one_dimensional = r2_score(set_3, set_4)
-    Numba.enable_numba()
-    with_numba = r2_score(set_1, set_2)
-    with_numba_one_dimensional = r2_score(set_3, set_4)
-    assert state == Numba.numba_flag  # Ensure that inital state = final state
-    assert np.allclose(non_numba, with_numba)
-    assert np.allclose(non_numba_one_dimensional, with_numba_one_dimensional)
